# README #

### Как поднять проект локально? ###

Можно использовать прилагаемый docker-compose файл:

```
curl -sSL https://raw.githubusercontent.com/python-poetry/poetry/master/get-poetry.py | python3.9
cd dev
docker-compose --project-name voxlane-back -f workspace/voxlane-back/dev/docker-compose.local.yml up```

Для запуска приложения требуется чтобы папка `app` в корне репозитория была добавлена в `PYTHONPATH`.

В Pycharm для этого достаточно отметить её как `Sources Root`.

Затем создайте файл `app/main/settings_local.py` со следующим содержимым:

Прочтите файл, некоторые настройки потребуется заполнить вручную.

```python
import datetime

DEBUG = True

# убираем настройки безопасности
ALLOWED_HOSTS = ['*']
SIMPLE_JWT = {
    'ACCESS_TOKEN_LIFETIME': datetime.timedelta(days=30),
    'REFRESH_TOKEN_LIFETIME': datetime.timedelta(hours=3),
    'AUTH_HEADER_TYPES': ('Bearer',),
    'ROTATE_REFRESH_TOKENS': True
}
AUTH_PASSWORD_VALIDATORS = []
USE_HTTPS = False
SESSION_COOKIE_SECURE = False
CSRF_COOKIE_SECURE = False

# сначала пытаемся аутентифицироваться через Django
AUTHENTICATION_BACKENDS = [
    'django.contrib.auth.backends.ModelBackend',
]

# БД
DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.postgresql_psycopg2',
        'HOST': 'localhost',
        'PORT': '35432',
        'NAME': 'voxlane',
        'USER': 'thirdlane',
        'PASSWORD': 'thirdlane',
    }
}

# исходящая почта
EMAIL_HOST = 'localhost'
EMAIL_PORT = '1025'

# redis и celery
REDIS_HOST = 'localhost'
REDIS_PORT = '36379'
REDIS_DB_CELERY = 0

CELERY_BROKER_URL = f"redis://{REDIS_HOST}:{REDIS_PORT}/{REDIS_DB_CELERY}"
CELERY_RESULT_BACKEND = f"redis://{REDIS_HOST}:{REDIS_PORT}/{REDIS_DB_CELERY}"

CACHES = {
    "default": {
        "BACKEND": "django_redis.cache.RedisCache",
        "LOCATION": f"redis://{REDIS_HOST}:{REDIS_PORT}/1",
        "OPTIONS": {
            "CLIENT_CLASS": "django_redis.client.DefaultClient",
        }
    }
}

# упрощает отладку вычисляемых полей в моделях
COMPUTEDFIELDS_MAP = None
COMPUTEDFIELDS_ADMIN = True
```
Переменные, добавленные в него, будут автоматически добавляться(перезаписывать существующие переменные) в базовых настройках в `app/main/settings.py`

В конфигурацию входит почтовый сервер, можно читать исходящие письма в веб интерфейсе на http://localhost:8025/

Также в конфигурацию входит сервер rabbitmq, админка доступна на http://localhost:8030/ логин/пароль guest/guest

### Фронтенд ###

Фронтенд поднимается отдельно, но по умолчанию настроен на работу с локальным бекендом.
Репозиторий фронтенда:

### Как запускать celery task'и без отдельного процесса? ###

Добавьте к вашему файлу настроек `CELERY_TASK_ALWAYS_EAGER = True`

### Как запускать celery на windows? ###

Celery на windows запустится, но "из коробки" не будет выполнять таски, нужно запускать следующим образом:

`celery -A main worker --loglevel=INFO --pool=solo`
