from django.contrib.auth import get_user_model
from rest_framework_simplejwt.serializers import (
    TokenObtainPairSerializer,
    TokenVerifySerializer,
    TokenRefreshSerializer,
)
from rest_framework_simplejwt.state import token_backend
from rest_framework_simplejwt.tokens import RefreshToken

from users.serializers import UserSerializer

User = get_user_model()


class TokenObtainPairSerializerEx(TokenObtainPairSerializer):
    def validate(self, attrs):
        data = super().validate(attrs)
        data["user"] = UserSerializer(self.user).data
        return data


class TokenVerifySerializerEx(TokenVerifySerializer):
    def validate(self, attrs):
        data = super().validate(attrs)
        payload = token_backend.decode(attrs["token"], verify=False)
        user = User.objects.get(id=payload.get("user_id"))
        data["user"] = UserSerializer(user).data
        return data


class TokenRefreshSerializerEx(TokenRefreshSerializer):
    def validate(self, attrs):
        data = super().validate(attrs)
        refresh = RefreshToken(attrs["refresh"])
        user = User.objects.get(id=refresh.payload.get("user_id"))
        data["user"] = UserSerializer(user).data
        return data
