import os

from celery import Celery
from celery.signals import task_failure

# set the default Django settings module for the 'celery' program.
os.environ.setdefault("DJANGO_SETTINGS_MODULE", "main.settings")

app = Celery("voxlane")

# Using a string here means the worker doesn't have to serialize
# the configuration object to child processes.
# - namespace='CELERY' means all celery-related configuration keys
#   should have a `CELERY_` prefix.
app.config_from_object("django.conf:settings", namespace="CELERY")


def periodic(schedule):
    """
    Decorator to run a task on a schedule.
    see https://docs.celeryproject.org/en/v4.4.7/userguide/periodic-tasks.html
    :param schedule: - interval in seconds/cron/solar
    """

    def decorator(task):
        app.add_periodic_task(schedule, task)
        return task

    return decorator


@app.on_after_configure.connect
def setup_periodic_tasks(sender, **kwargs):
    # you can add periodic tasks here
    pass


@task_failure.connect
def celery_task_failure_email(sender, **kwargs):
    from django.core.mail import mail_admins
    from django.conf import settings

    queue_name = sender.request.delivery_info.get("routing_key", "celery")
    subject = f"[Task Failure][{queue_name}@{settings.PRIMARY_HOST}] {sender.name} error"
    message = (
        f"Task {sender.name} has failed. \n " f"Task id was: {kwargs['task_id']} \n " f"Traceback: \n {kwargs['einfo']}"
    )
    mail_admins(subject, message)


# Load task modules from all registered Django app configs.
app.autodiscover_tasks()
