"""
Django settings for voxlane-back project.

Generated by 'django-admin startproject' using Django 3.0.7.

For more information on this file, see
https://docs.djangoproject.com/en/3.0/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/3.0/ref/settings/
"""
import datetime
import os
import sys
import uuid

# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))

# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/3.0/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = "48#xjh0!2+k7uq%tb!lt7mz2!1)3wm@2u8q(*(6**45sx^6lcl"

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = os.environ.get("DEBUG", "").lower() == "true"
DOCKER = bool(os.environ.get("DOCKER", False))
QA = os.environ.get("QA", "").lower() == "true"
PRODUCTION = os.environ.get("PRODUCTION", "").lower() == "true"
TEST = "test" in sys.argv

ALLOWED_HOSTS = [host.strip() for host in os.environ.get("ALLOWED_HOSTS", "").split(",") if host.strip()]
ADMINS = [(email.strip(), email.strip()) for email in os.environ.get("ADMINS", "").strip().split(",") if email.strip()]
PRIMARY_HOST = os.environ.get("PRIMARY_HOST", "execution").lower()

# HTTPS

USE_HTTPS = os.environ.get("USE_HTTPS", "true").lower() == "true"
SESSION_COOKIE_SECURE = USE_HTTPS
CSRF_COOKIE_SECURE = USE_HTTPS
# TODO: set up HSTS

APPEND_SLASH = True

# Application definition

INSTALLED_APPS = [
    "django.contrib.admin",
    "django.contrib.auth",
    "django.contrib.contenttypes",
    "django.contrib.sessions",
    "django.contrib.messages",
    "django.contrib.staticfiles",
    "computedfields",
    "rest_framework",
    "django_filters",
    "django_cron",
    "corsheaders",
    "mptt",
    "tenants.apps.TenantsConfig",
    "tags.apps.TagConfig",
    "task_templates.apps.TaskTemplateConfig",
    "tasks.apps.TasksConfig",
    "clients.apps.ClientsConfig",
    "users.apps.UsersConfig",  # users should be last in this list, or permission update may fail
]

REST_FRAMEWORK = {
    "DEFAULT_PERMISSION_CLASSES": ("rest_framework.permissions.IsAuthenticated",),
    "DEFAULT_AUTHENTICATION_CLASSES": (
        "rest_framework_simplejwt.authentication.JWTAuthentication",
        "rest_framework.authentication.SessionAuthentication",
        "rest_framework.authentication.BasicAuthentication",
    ),
    "DEFAULT_FILTER_BACKENDS": (
        "django_filters.rest_framework.DjangoFilterBackend",
        "rest_framework.filters.SearchFilter",
        "main.core.filters.NestedOrderingFilter",
    ),
    "DEFAULT_PAGINATION_CLASS": "main.core.pagination.DefaultVLNPagination",
}

SIMPLE_JWT = {
    "ACCESS_TOKEN_LIFETIME": datetime.timedelta(minutes=30),
    "REFRESH_TOKEN_LIFETIME": datetime.timedelta(hours=3),
    "AUTH_HEADER_TYPES": ("Bearer",),
    "ROTATE_REFRESH_TOKENS": True,
}

MIDDLEWARE = [
    "django.middleware.security.SecurityMiddleware",
    "django.contrib.sessions.middleware.SessionMiddleware",
    "corsheaders.middleware.CorsMiddleware",
    "django.middleware.common.CommonMiddleware",
    "django.middleware.csrf.CsrfViewMiddleware",
    "django.contrib.auth.middleware.AuthenticationMiddleware",
    "django.contrib.messages.middleware.MessageMiddleware",
    "django.middleware.clickjacking.XFrameOptionsMiddleware",
    "main.core.middleware.VLNMiddleware",  # should be last
]

ROOT_URLCONF = "main.urls"

TEMPLATES = [
    {
        "BACKEND": "django.template.backends.django.DjangoTemplates",
        "DIRS": [],
        "APP_DIRS": True,
        "OPTIONS": {
            "context_processors": [
                "django.template.context_processors.debug",
                "django.template.context_processors.request",
                "django.contrib.auth.context_processors.auth",
                "django.contrib.messages.context_processors.messages",
            ],
        },
    },
]

WSGI_APPLICATION = "main.wsgi.application"

CORS_ORIGIN_ALLOW_ALL = True  # If this is used then `CORS_ORIGIN_WHITELIST` will not have any effect
CORS_ALLOW_CREDENTIALS = True
CORS_ORIGIN_WHITELIST = [
    "http://localhost:4200",
]  # If this is used, then not need to use `CORS_ORIGIN_ALLOW_ALL = True`
CORS_ORIGIN_REGEX_WHITELIST = [
    "http://localhost:4200",
]

# Database
# https://docs.djangoproject.com/en/3.0/ref/settings/#databases

DATABASES = {
    "default": {
        "ENGINE": "django.db.backends.postgresql_psycopg2",
        "HOST": os.environ.get("DB_HOST", "127.0.0.1"),
        "PORT": os.environ.get("DB_PORT", "5432"),
        "NAME": os.environ.get("DB_NAME", "voxlane"),
        "USER": os.environ.get("DB_USER", "thirdlane"),
        "PASSWORD": os.environ.get("DB_PASSWORD", "thirdlane"),
    }
}


AUTH_USER_MODEL = "users.User"

AUTHENTICATION_BACKENDS = [
    "django.contrib.auth.backends.ModelBackend",
]

# Password validation
# https://docs.djangoproject.com/en/3.0/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = [
    {
        "NAME": "django.contrib.auth.password_validation.UserAttributeSimilarityValidator",
    },
    {
        "NAME": "django.contrib.auth.password_validation.MinimumLengthValidator",
    },
    {
        "NAME": "django.contrib.auth.password_validation.CommonPasswordValidator",
    },
    {
        "NAME": "django.contrib.auth.password_validation.NumericPasswordValidator",
    },
]

# Internationalization
# https://docs.djangoproject.com/en/3.0/topics/i18n/

LANGUAGE_CODE = "en"

LANGUAGES = [
    ("en", "English"),
]

TIME_ZONE = "America/New_York"

USE_I18N = True

USE_L10N = True

USE_TZ = True

LOCALE_PATHS = (os.path.join(os.path.dirname(BASE_DIR), "locale"),)

# computed fields
COMPUTEDFIELDS_MAP = "/computed_fields.map" if DOCKER else None
COMPUTEDFIELDS_ADMIN = DEBUG

# Integrations

# UI_URL = os.environ.get('UI_URL', '')

# Cron Jobs
# CRON_CLASSES = [
#     'integration.crons.ClientCronJob',
# ]
DJANGO_CRON_DELETE_LOGS_OLDER_THAN = 14  # days

# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/3.0/howto/static-files/

STATIC_URL = "/static/"
STATIC_ROOT = os.path.join(os.path.dirname(BASE_DIR), "static")
STATICFILES_DIRS = [
    os.path.join(os.path.join(BASE_DIR), "static"),
]

# Mail

EMAIL_HOST = os.environ.get("EMAIL_HOST", "")
EMAIL_HOST_USER = os.environ.get("EMAIL_HOST_USER", "")
EMAIL_HOST_PASSWORD = os.environ.get("EMAIL_HOST_PASSWORD", "")
EMAIL_PORT = os.environ.get("EMAIL_PORT", "25")
EMAIL_USE_TLS = os.environ.get("EMAIL_USE_TLS", "").lower() == "true"
DEFAULT_FROM_EMAIL = os.environ.get("DEFAULT_FROM_EMAIL", f"noreply@{PRIMARY_HOST}")
EMAIL_SUBJECT_PREFIX = os.environ.get("EMAIL_SUBJECT_PREFIX", "[EXEC]")
EMAIL_REDIRECT_ALL_TO = [
    email.strip() for email in os.environ.get("EMAIL_REDIRECT_ALL_TO", "").split(",") if email.strip()
]

REDIS_HOST = os.environ.get("REDIS_HOST", "localhost")
REDIS_PORT = os.environ.get("REDIS_PORT", "6379")
REDIS_DB_CELERY = "0"
REDIS_DB_CACHE = "1"

CELERY_BROKER_URL = f"redis://{REDIS_HOST}:{REDIS_PORT}/{REDIS_DB_CELERY}"
CELERY_RESULT_BACKEND = f"redis://{REDIS_HOST}:{REDIS_PORT}/{REDIS_DB_CELERY}"
CELERY_RESULT_EXPIRES = 3600  # seconds
CELERY_TRACK_STARTED = True
# CELERY_TIMEZONE = TZ

COMMENT_EDITING_LIFETIME_MIN = os.environ.get("COMMENT_EDITING_LIFETIME_MIN", "30")

CACHES = {
    "default": {
        "BACKEND": "django_redis.cache.RedisCache",
        "LOCATION": f"redis://{REDIS_HOST}:{REDIS_PORT}/{REDIS_DB_CACHE}",
        "OPTIONS": {
            "CLIENT_CLASS": "django_redis.client.DefaultClient",
        },
    }
}

LOGGING = {
    "version": 1,
    "disable_existing_loggers": False,
    "filters": {
        "require_debug_false": {
            "()": "django.utils.log.RequireDebugFalse",
        },
        "require_debug_true": {
            "()": "django.utils.log.RequireDebugTrue",
        },
    },
    "handlers": {
        "console_debug": {
            "level": "DEBUG",
            "class": "logging.StreamHandler",
            "formatter": "short",
            "filters": ["require_debug_true"],
        },
        "stdout": {
            "level": "WARNING",
            "class": "logging.StreamHandler",
            "formatter": "verbose",
            "filters": ["require_debug_false"],
        },
    },
    "formatters": {
        "verbose": {"format": "[%(levelname)s] %(asctime)s %(module)s PID=%(process)d %(message)s"},
        "short": {"format": "[%(levelname)s] %(message)s"},
    },
    "loggers": {
        "django.request": {
            "handlers": ["stdout", "console_debug"],
            "level": "INFO",
            "propagate": False,
        },
        "django.db.backends": {
            "level": "DEBUG",
            "handlers": ["console_debug"],
            "propagate": False,
        },
        "": {
            "handlers": ["stdout", "console_debug"],
            "level": "INFO",
            "propagate": False,
        },
    },
}

try:
    from .settings_local import *
except ImportError:
    pass
