"""voxlane-back URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/3.0/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
from clients.views import TenantClientViewSet
from django.contrib import admin
from django.contrib.auth import views as auth_views
from django.urls import include, path
from main.auth.views import TokenObtainPairViewEx, TokenRefreshViewEx, TokenVerifyViewEx
from main.core.routers import VLNNestedRouter, VLNRouter
from tags.views import TenantTagViewSet
from task_templates.views import TenantTaskTemplateViewSet
from tasks.views import TaskViewSet
from tenants.views import TenantViewSet
from users.views import TenantUsersViewSet, UserViewSet

router = VLNRouter()
router.register("users", UserViewSet, basename="users")
router.register("tenants", TenantViewSet, basename="tenants")
router.register("tasks", TaskViewSet, basename="tasks")

# tenant sub-views
tenants_router = VLNNestedRouter(router, "tenants", lookup="tenant")
tenants_router.register("users", TenantUsersViewSet, basename="users")
tenants_router.register("task-templates", TenantTaskTemplateViewSet, basename="task-templates")
tenants_router.register("clients", TenantClientViewSet, basename="clients")
tenants_router.register("tags", TenantTagViewSet, basename="tags")

api_routes = [
    path("", include(router.urls)),
    path("", include(tenants_router.urls)),
    path("token/auth", TokenObtainPairViewEx.as_view()),
    path("token/refresh", TokenRefreshViewEx.as_view()),
    path("token/verify", TokenVerifyViewEx.as_view()),
]

urlpatterns = [
    path("api/v1/", include(api_routes)),
    path("admin/", admin.site.urls),
    path("accounts/login/", auth_views.LoginView.as_view(**{"template_name": "admin/login.html"})),
]
