from django.core.serializers.json import DjangoJSONEncoder
from django.db import models
from main.core.models import UUIDIDMixin
from task_templates.constants import TaskTemplateType


def get_default_task_template_meta():
    return {}


class TaskTemplate(UUIDIDMixin):
    name = models.CharField("Name", max_length=254)
    meta_info = models.JSONField(default=get_default_task_template_meta, encoder=DjangoJSONEncoder)
    type = models.CharField("Type", max_length=32, choices=TaskTemplateType.choices, default=TaskTemplateType.VOICE)

    tenant = models.ForeignKey("tenants.Tenant", related_name="task_templates", on_delete=models.CASCADE)

    class Meta:
        app_label = "tasks"
        db_table = "task_templates"
        verbose_name = "Task template"
        verbose_name_plural = "Task templates"

    def __str__(self):
        return f"{self.name}"
