import uuid

from django.conf import settings
from django.core.serializers.json import DjangoJSONEncoder
from django.db import models
from main.core.models import BaseAuditTrack, UUIDIDMixin
from tasks.constants import TaskStatus, TaskType


def get_default_task_meta():
    return {}


class Task(UUIDIDMixin, BaseAuditTrack):
    type = models.CharField("Type", max_length=32, choices=TaskType.choices, default=TaskType.VOICE)
    status = models.CharField("Status", max_length=32, choices=TaskStatus.choices, default=TaskStatus.NEW)
    recording_id = models.UUIDField("Record id", default=uuid.uuid4, editable=False)
    meta_info = models.JSONField(default=get_default_task_meta, encoder=DjangoJSONEncoder)

    task_template = models.ForeignKey("tasks.TaskTemplate", related_name="tasks", on_delete=models.CASCADE)
    client = models.ForeignKey("clients.Client", related_name="tasks", on_delete=models.CASCADE)
    assignee = models.ForeignKey(settings.AUTH_USER_MODEL, related_name="tasks", on_delete=models.CASCADE)

    class Meta:
        app_label = "tasks"
        db_table = "tasks"
        verbose_name = "Task"
        verbose_name_plural = "Task"

    def __str__(self):
        return f"{self.name}"
