from django import forms
from django.contrib import admin
from django.contrib.admin import ModelAdmin, widgets
from django.contrib.admin.sites import NotRegistered
from django.contrib.auth.models import Group
from users.models import User


class UserAdmin(ModelAdmin):
    search_fields = (
        "username",
        "last_name",
        "first_name",
    )
    list_display = ("username", "last_name", "first_name", "tenant")
    list_filter = ("is_active",)

    readonly_fields = ("username", "is_superuser")
    autocomplete_fields = ["tenant"]
    fieldsets = (
        (
            None,
            {
                "fields": (
                    "username",
                    "last_name",
                    "first_name",
                    "email",
                    "tenant",
                    "is_superuser",
                )
            },
        ),
    )

    def has_add_permission(self, request):
        return False


class GroupForm(forms.ModelForm):
    name = forms.CharField(disabled=True)
    users = forms.ModelMultipleChoiceField(
        User.objects.all(), label="Users", required=False, widget=widgets.FilteredSelectMultiple("Users", False)
    )

    class Meta:
        model = Group
        exclude = ["permissions"]

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        if self.instance.pk:
            self.fields["users"].initial = self.instance.user_set.all()

    def save(self, *args, **kwargs):
        instance = super().save(*args, **kwargs)
        self.instance.user_set.set(self.cleaned_data["users"])
        return instance


class GroupAdmin(admin.ModelAdmin):
    form = GroupForm
    search_fields = ("name",)
    ordering = ("name",)

    def has_delete_permission(self, request, obj=None):
        return False

    def has_add_permission(self, request):
        return False


admin.site.register(User, UserAdmin)

try:
    admin.site.unregister(Group)
    admin.site.register(Group, GroupAdmin)
except NotRegistered:
    pass
