from django.contrib.auth.models import AbstractUser
from django.db import models
from main.core.models import UUIDIDMixin
from users.constants import UserGroup, UserPermission


class User(AbstractUser, UUIDIDMixin):
    Group = UserGroup
    Permission = UserPermission
    tenant = models.ForeignKey("tenants.Tenant", related_name="users", null=True, blank=True, on_delete=models.CASCADE)

    class Meta:
        verbose_name = "User"
        verbose_name_plural = "Users"
        permissions = [
            (UserPermission.Raw.IS_MANAGER, "MANAGER"),
            (UserPermission.Raw.IS_OPERATOR, "OPERATOR"),
        ]

    @property
    def full_name(self) -> str:
        if self.first_name or self.last_name:
            return " ".join([self.last_name, self.first_name])
        elif self.username:
            return self.username
        else:
            return "Unknown user"
