from main.core.serializers import (
    ForeignKeyDeserializerMixin,
    NestedRouterForeignKeyDeserializerMixin,
)
from rest_framework import fields, serializers
from rest_framework.exceptions import ValidationError
from rest_framework.fields import ReadOnlyField
from users.models import User


class UserGroupsSerializer(fields.Field):
    def to_representation(self, value):
        return [group.name for group in value.all()]

    def to_internal_value(self, data):
        if not isinstance(data, list):
            raise ValidationError("Groups must be a list of strings")
        for name in data:
            if not isinstance(name, str):
                raise ValidationError("Group name must be a string")
        return data


class UserShortSerializer(serializers.ModelSerializer):
    class Meta:
        model = User
        fields = ("id", "username", "first_name", "last_name", "email")


class UserSerializer(serializers.ModelSerializer):
    class Meta:
        model = User
        read_only_fields = ("object_guid",)
        exclude = ("date_joined", "last_login", "password", "user_permissions")

    groups = UserGroupsSerializer(read_only=True)
    permissions = serializers.SerializerMethodField()
    is_purchase_lead = ReadOnlyField()
    is_ko_lead = ReadOnlyField()
    is_do_lead = ReadOnlyField()
    is_chief_commercial_officer = ReadOnlyField()
    is_logistics_lead = ReadOnlyField()
    is_service_lead = ReadOnlyField()
    is_engineering_lead = ReadOnlyField()

    @staticmethod
    def get_permissions(user):
        return user.get_all_permissions()


class TenantUsersSerializer(NestedRouterForeignKeyDeserializerMixin, UserSerializer):
    router_lookups = ("tenant",)
