from django.contrib.auth.models import Group
from django.test import TestCase

from users.constants import UserGroup
from users.tests.factories import UserFactory


class UserTestCase(TestCase):
    def test_group_admin_sync(self):
        admin_group = Group.objects.get(name=UserGroup.ADMINISTRATOR)
        user = UserFactory(username="test", email="test@example.com", password="secret")
        self.assertFalse(user.is_superuser)
        self.assertFalse(user.is_staff)

        user.groups.add(admin_group)
        user.refresh_from_db()
        self.assertTrue(user.is_superuser)
        self.assertTrue(user.is_staff)

        user.groups.remove(admin_group)
        user.refresh_from_db()
        self.assertFalse(user.is_superuser)
        self.assertFalse(user.is_staff)
