import logging

from django.conf import settings

from main.core.middleware import CurrentRequest
from main.core.utils import get_request_from_stack
from users.constants import DELETED_USER_NAME, SYSTEM_USER_NAME

logger = logging.getLogger(__name__)


def get_permissions_as_dict():
    from django.apps import apps

    Permission = apps.get_model("auth", "Permission")
    all_permissions = Permission.objects.select_related("content_type").all()
    return {f"{p.content_type.app_label}.{p.codename}": p for p in all_permissions}


@CurrentRequest.cached
def get_placeholder_for_deleted_user():
    from users.models import User

    """
    This user should own all resources created by deleted users
    :return: User
    """
    return User.objects.get(username=DELETED_USER_NAME)


@CurrentRequest.cached
def get_system_user():
    from users.models import User

    return User.objects.get(username=SYSTEM_USER_NAME)


# @CurrentRequest.cached
# def get_crm_user():
#     from users.models import User
#     return User.objects.get(username=CRM_USER_NAME)


def get_actor_user():
    if CurrentRequest.user:
        return CurrentRequest.user
    request = get_request_from_stack()
    user = getattr(request, "user", None)
    if user:
        return user
    return get_system_user()
