from main.core.permissions import VLNModelPermissions
from main.core.views import VLNModelViewSet
from rest_framework.decorators import action
from rest_framework.permissions import IsAuthenticated
from rest_framework.response import Response
from users.filters import UserFilter
from users.models import User
from users.serializers import TenantUsersSerializer, UserSerializer, UserShortSerializer


class UserViewSet(VLNModelViewSet):
    permission_classes = (VLNModelPermissions,)
    serializer_class = UserShortSerializer
    filterset_class = UserFilter
    queryset = User.objects.all()
    ordering = ["-id"]
    search_fields = (
        "username",
        "last_name",
        "first_name",
    )

    @action(methods=("GET",), detail=False, permission_classes=(IsAuthenticated,))
    def me(self, request):
        serializer = UserSerializer(self.request.user)
        return Response(serializer.data)


class TenantUsersViewSet(VLNModelViewSet):
    serializer_class = TenantUsersSerializer
    pagination_class = None
